@@ -239,7 +239,57 @@ class WAxisManager(Ui_WAxisManager, QWidget):
         ]:
             action_selected = self.w_axis_1.get_current_action_name()
             self.w_axis_2.set_action(action_selected)
+            if action_selected == "FFT":
+                if self.w_axis_2.axis_selected in fft_dict:
+                    if self.w_axis_2.axis_selected in self.w_axis_2.axes_list:
+                        self.w_axis_2.axes_list[
+                            self.w_axis_2.axes_list.index(self.w_axis_2.axis_selected)
+                        ] = fft_dict[self.w_axis_2.axis_selected]
+                        self.w_axis_2.axis_selected = fft_dict[
+                            self.w_axis_2.axis_selected
+                        ]
+                    else:
+                        self.w_axis_2.axis_selected = fft_dict[
+                            self.w_axis_2.axis_selected
+                        ]
+                elif self.w_axis_2.axis_selected in ifft_dict:
+                    if (
+                        self.w_axis_2.axis_selected not in self.w_axis_2.axes_list
+                        and ifft_dict[self.w_axis_2.axis_selected]
+                        in self.w_axis_2.axes_list
+                    ):
+                        self.w_axis_2.axes_list[
+                            self.w_axis_2.axes_list.index(
+                                ifft_dict[self.w_axis_2.axis_selected]
+                            )
+                        ] = self.w_axis_2.axis_selected
+            else:
+                if self.w_axis_2.axis_selected in ifft_dict:
+                    if self.w_axis_2.axis_selected in self.w_axis_2.axes_list:
+                        self.w_axis_2.axes_list[
+                            self.w_axis_2.axes_list.index(self.w_axis_2.axis_selected)
+                        ] = ifft_dict[self.w_axis_2.axis_selected]
+                        self.w_axis_2.axis_selected = ifft_dict[
+                            self.w_axis_2.axis_selected
+                        ]
+                    else:
+                        self.w_axis_2.axis_selected = ifft_dict[
+                            self.w_axis_2.axis_selected
+                        ]
+                elif self.w_axis_2.axis_selected in fft_dict:
+                    if (
+                        self.w_axis_2.axis_selected not in self.w_axis_2.axes_list
+                        and fft_dict[self.w_axis_2.axis_selected]
+                        in self.w_axis_2.axes_list
+                    ):
+                        self.w_axis_2.axes_list[
+                            self.w_axis_2.axes_list.index(
+                                fft_dict[self.w_axis_2.axis_selected]
+                            )
+                        ] = self.w_axis_2.axis_selected
             self.gen_slice_op()
+            self.w_axis_1.set_unit()
+            self.w_axis_2.set_unit()
 
         elif axis_changed == "axis 2" and "FFT" in [
             self.w_axis_2.c_action.itemText(i)
@@ -247,7 +297,57 @@ class WAxisManager(Ui_WAxisManager, QWidget):
         ]:
             action_selected = self.w_axis_2.get_current_action_name()
             self.w_axis_1.set_action(action_selected)
+            if action_selected == "FFT":
+                if self.w_axis_1.axis_selected in fft_dict:
+                    if self.w_axis_1.axis_selected in self.w_axis_1.axes_list:
+                        self.w_axis_1.axes_list[
+                            self.w_axis_1.axes_list.index(self.w_axis_1.axis_selected)
+                        ] = fft_dict[self.w_axis_1.axis_selected]
+                        self.w_axis_1.axis_selected = fft_dict[
+                            self.w_axis_1.axis_selected
+                        ]
+                    else:
+                        self.w_axis_1.axis_selected = fft_dict[
+                            self.w_axis_1.axis_selected
+                        ]
+                elif self.w_axis_1.axis_selected in ifft_dict:
+                    if (
+                        self.w_axis_1.axis_selected not in self.w_axis_1.axes_list
+                        and ifft_dict[self.w_axis_1.axis_selected]
+                        in self.w_axis_1.axes_list
+                    ):
+                        self.w_axis_1.axes_list[
+                            self.w_axis_1.axes_list.index(
+                                ifft_dict[self.w_axis_1.axis_selected]
+                            )
+                        ] = self.w_axis_1.axis_selected
+            else:
+                if self.w_axis_1.axis_selected in ifft_dict:
+                    if self.w_axis_1.axis_selected in self.w_axis_1.axes_list:
+                        self.w_axis_1.axes_list[
+                            self.w_axis_1.axes_list.index(self.w_axis_1.axis_selected)
+                        ] = ifft_dict[self.w_axis_1.axis_selected]
+                        self.w_axis_1.axis_selected = ifft_dict[
+                            self.w_axis_1.axis_selected
+                        ]
+                    else:
+                        self.w_axis_1.axis_selected = ifft_dict[
+                            self.w_axis_1.axis_selected
+                        ]
+                elif self.w_axis_1.axis_selected in fft_dict:
+                    if (
+                        self.w_axis_1.axis_selected not in self.w_axis_1.axes_list
+                        and fft_dict[self.w_axis_1.axis_selected]
+                        in self.w_axis_1.axes_list
+                    ):
+                        self.w_axis_1.axes_list[
+                            self.w_axis_1.axes_list.index(
+                                fft_dict[self.w_axis_1.axis_selected]
+                            )
+                        ] = self.w_axis_1.axis_selected
             self.gen_slice_op()
+            self.w_axis_1.set_unit()
+            self.w_axis_2.set_unit()
 
     def set_axis_widgets(
         self,
@@ -267,7 +367,8 @@ class WAxisManager(Ui_WAxisManager, QWidget):
         axes_request_list:
             list of RequestedAxis which are the info given for the autoplot (for the axes and DataSelection)
         frozen_type : int
-            0 to let the user modify the axis of the plot, 1 to let him switch them, 2 to not let him change them, 3 to freeze both axes and operations, 4 to freeze fft
+            0 to let the user modify the axis of the plot, 1 to let him switch them, 2 to not let him change them,
+            3 to freeze both axes and operations, 4 to freeze fft, 5 to only allow switch
         path_to_image : str
             path to the folder where the image for the animation button is saved
         """
@@ -279,7 +380,7 @@ class WAxisManager(Ui_WAxisManager, QWidget):
         if is_keep_config:  # Only update slider
             for wid in self.w_slice_op:
                 if hasattr(wid, "axis_value"):
-                    wid.update_floatEdit(is_refresh=False)
+                    wid.update_floatEdit()
             axes_list = data.get_axes()
 
         else:
@@ -385,7 +486,6 @@ class WAxisManager(Ui_WAxisManager, QWidget):
 
             # Freezing the operations
             for w_slice in self.w_slice_op:
-                w_slice.b_action.setDisabled(True)
                 w_slice.c_operation.setDisabled(True)
                 w_slice.lf_value.setDisabled(True)
                 w_slice.slider.setDisabled(True)
@@ -400,6 +500,18 @@ class WAxisManager(Ui_WAxisManager, QWidget):
             ):
                 self.w_axis_2.c_action.setDisabled(True)
 
+        elif frozen_type == 5:
+            # Freezing the axes
+            self.w_axis_1.c_action.setDisabled(True)
+            self.w_axis_2.c_action.setDisabled(True)
+
+            # Freezing the operations
+            for w_slice in self.w_slice_op:
+                w_slice.b_action.setDisabled(True)
+                w_slice.c_operation.setDisabled(True)
+                w_slice.lf_value.setDisabled(True)
+                w_slice.slider.setDisabled(True)
+
         if len(axes_list) == 1:
             self.w_axis_2.hide()
 
