@@ -168,6 +168,9 @@ class WAxisSelector(Ui_WAxisSelector, QWidget):
 
             # Building the new ComboBox
             self.c_axis.blockSignals(True)
+            index = 0
+            if self.c_axis.currentText() != "None":
+                index = self.c_axis.currentIndex()
             self.c_axis.clear()
 
             for ax in axes_list:
@@ -178,6 +181,7 @@ class WAxisSelector(Ui_WAxisSelector, QWidget):
 
             update_cb_enable(self.c_axis)
             self.c_axis.blockSignals(False)
+            self.c_axis.setCurrentIndex(index)
 
             self.update_axis(is_refresh=False)
 
@@ -210,6 +214,8 @@ class WAxisSelector(Ui_WAxisSelector, QWidget):
 
         # Step 2 : Recovering the unit and setting the combobox according to it
         unit_name = axis.unit
+        self.c_unit.blockSignals(True)
+        self.set_unit()
         if self.c_unit.findText(unit_name) != -1:
             self.c_unit.setCurrentIndex(self.c_unit.findText(unit_name))
         elif unit_name in unit_dict:
@@ -220,6 +226,7 @@ class WAxisSelector(Ui_WAxisSelector, QWidget):
             self.c_unit.setCurrentIndex(0)
         else:
             self.c_unit.setCurrentIndex(self.c_unit.findText(unit_name))
+        self.c_unit.blockSignals(False)
 
         self.blockSignals(False)
 
@@ -314,10 +321,10 @@ class WAxisSelector(Ui_WAxisSelector, QWidget):
             name of the new action"""
 
         action_list = [self.c_action.itemText(i) for i in range(self.c_action.count())]
-        self.blockSignals(True)
+        self.c_action.blockSignals(True)
         if action in action_list and action != "Filter":
             self.c_action.setCurrentIndex(action_list.index(action))
-        self.blockSignals(False)
+        self.c_action.blockSignals(False)
 
     def set_unit(self):
         """Method that update the unit comboxbox according to the axis selected in the other combobox.
@@ -334,6 +341,7 @@ class WAxisSelector(Ui_WAxisSelector, QWidget):
             self.c_unit.clear()
             self.c_unit.setDisabled(True)
         else:
+            unit_index = self.c_unit.currentIndex()
             self.c_unit.setDisabled(False)
             self.c_unit.clear()
 
@@ -360,7 +368,8 @@ class WAxisSelector(Ui_WAxisSelector, QWidget):
                 self.c_unit.setCurrentIndex(idx_unit)
                 if len(self.c_unit.currentText()) > cb_width:
                     cb_width = len(self.c_unit.currentText())
-            self.c_unit.setCurrentIndex(0)
+            if unit_index != -1:
+                self.c_unit.setCurrentIndex(unit_index)
 
             self.c_unit.view().setMinimumWidth(cb_width * 8)
 
@@ -383,10 +392,9 @@ class WAxisSelector(Ui_WAxisSelector, QWidget):
         self.set_name(axis_name)
         self.set_axis_options(axes_list)
         self.update_axis()
-        self.c_action.setCurrentIndex(0)
         self.set_unit()
 
-    def update_axis(self, is_refresh=True):
+    def update_axis(self, text=None, is_refresh=True):
         """Method called when an axis is changed that change axis_selected, the units available and the action combobox.
         It will also emit a signal used in WAxisManager.
         Parameters
@@ -394,8 +402,9 @@ class WAxisSelector(Ui_WAxisSelector, QWidget):
         self : WAxisSelector
             a WAxisSelector object
         """
-
-        self.c_action.setCurrentIndex(0)
+        self.c_action.blockSignals(True)
+        if is_refresh:
+            self.c_action.setCurrentIndex(0)
 
         if self.c_axis.currentText() == "None":
             self.c_action.setDisabled(True)
@@ -411,7 +420,8 @@ class WAxisSelector(Ui_WAxisSelector, QWidget):
         else:
             self.axis_selected = self.c_axis.currentText()
 
-        self.set_unit()
+        if not is_refresh:
+            self.set_unit()
 
         # Updating the action combobox
         # Handling specific case to disable certain parts of the GUI
@@ -420,7 +430,6 @@ class WAxisSelector(Ui_WAxisSelector, QWidget):
         else:
             self.c_action.setDisabled(False)
 
-        self.c_action.blockSignals(True)
         if self.axis_selected in fft_dict:
             action = ["None", "FFT"]
         elif (
@@ -434,10 +443,19 @@ class WAxisSelector(Ui_WAxisSelector, QWidget):
             action = ["None"]
         self.c_action.clear()
         self.c_action.addItems(action)
+        update_cb_enable(self.c_action)
         self.c_action.blockSignals(False)
 
         self.c_action.view().setMinimumWidth(max([len(ac) for ac in action]) * 6)
 
+        if "Filter" in action:
+            self.b_filter.show()
+        else:
+            sp_retain = self.b_filter.sizePolicy()
+            sp_retain.setRetainSizeWhenHidden(True)
+            self.b_filter.setSizePolicy(sp_retain)
+            self.b_filter.hide()
+
         # Emitting the signals
         if is_refresh:
             self.refreshNeeded.emit()
